pub struct AlbumsList {
pub success: bool,
pub albums: Vec<Album>,
pub home_domain: Option<Url>,
}Expand description
Album listing for the authenticated user.
Values produced by this crate always have success == true; failures are returned as
CyberdropError.
Fields
success: boolWhether the API request was successful.
albums: Vec<Album>Albums returned by the service.
home_domain: Option<Url>Optional home domain returned by the service, parsed as a URL.